#include "Def.h"
#include "OBJ_IO.h"
#include "MyGLWindow.h"
#include "string.h"
#include <FL/Fl_Round_Button.h>
#include <FL/FL_Choice.H>
int		SHADING_STATE = 1;	//use last three bits as wireframe, flatshading, combo
char	SubAlg[200];
char	SimAlg[200];
char	ParAlg[200];


// a simple callback for the main window
void Subdivide_CB(Fl_Widget* /*button*/, MyGlWindow* myWind)
{
	if(strcmp(SubAlg, "Sqrt-3") == 0)
		myWind->subdivide_sqrt3();
	else if(strcmp(SubAlg, "Loops") == 0)
		myWind->subdivide_loops();
	myWind->damage(1);
}

void Simplify_CB(Fl_Widget* /*button*/, MyGlWindow* myWind)
{
	if(strcmp(SimAlg, "QEM") == 0)
		;//call your algorithm
	else if(strcmp(SimAlg, "Memoryless") == 0)
		;//call your algorithm
	myWind->damage(1);
}

void subdivide_menu_callback(Fl_Widget* widget)
{
    Fl_Choice* alg = (Fl_Choice*) widget;
	strcpy(SubAlg, alg->text());
} 

void simplify_menu_callback(Fl_Widget* widget)
{
    Fl_Choice* alg = (Fl_Choice*) widget;
	strcpy(SimAlg, alg->text());
} 


void Load_CB(Fl_Widget* /*button*/, MyGlWindow* myWind)
{
	myWind->load_Mesh();
	myWind->damage(1);
}

void Save_CB(Fl_Widget* /*button*/, MyGlWindow* myWind)
{
	myWind->save_Mesh();
}

void Redraw_CB(MyGlWindow* myWind)
{
	myWind->redraw();
}

void WireMode_CB(MyGlWindow* myWind)
{
	SHADING_STATE = 1;
}
void ShadeMode_CB(MyGlWindow* myWind)
{
	SHADING_STATE = 2;
}
void ComboMode_CB(MyGlWindow* myWind)
{
	SHADING_STATE = 4;
}


int main() 
{
	Fl_Double_Window* wind = new Fl_Double_Window(100,100,600,700,"GL Sample");

	wind->begin();		// put widgets inside of the window

		//create OpenGL window
		MyGlWindow* gl = new MyGlWindow(10,110,580, 580);

		//File IO button
		Fl_Button* load = new Fl_Button(5,10,80,25,"Load Mesh");
		Fl_Button* save = new Fl_Button(5,40,80,25,"Save Mesh");
		load->callback((Fl_Callback*) Load_CB, gl);
		save->callback((Fl_Callback*) Save_CB, gl);

		//shading mode button
		Fl_Group* o = new Fl_Group(10, 80, 450, 30);
		o->begin();
			Fl_Round_Button* w = new Fl_Round_Button(10, 80, 20, 30, "Wireframe");
			Fl_Round_Button* f = new Fl_Round_Button(110, 80, 20, 30, "Flatshade");
			Fl_Round_Button* s = new Fl_Round_Button(200, 80, 20, 30, "Shading+Wire");
			w->type(102);	f->type(102);	s->type(102);
			w->down_box(FL_ROUND_DOWN_BOX);
			f->down_box(FL_ROUND_DOWN_BOX);
			s->down_box(FL_ROUND_DOWN_BOX);
			w->callback((Fl_Callback*) WireMode_CB, gl);			
			f->callback((Fl_Callback*) ShadeMode_CB, gl);			
			s->callback((Fl_Callback*) ComboMode_CB, gl);
			w->value(1);
		o->end();

		//subdivision algorithm chooser
		Fl_Choice* sub = new Fl_Choice(180, 5 ,65,25, "Subdiv. Alg.");
		sub->add("Sqrt-3", 0, (Fl_Callback*)subdivide_menu_callback);
		sub->add("Loops", 0, (Fl_Callback*)subdivide_menu_callback);
		sub->add("others", 0, (Fl_Callback*)subdivide_menu_callback);
		Fl_Button* subdivide = new Fl_Button(100,40, 145 ,25,"Subdivide");
		subdivide->callback((Fl_Callback*) Subdivide_CB, gl);

		//simplification algorithm chooser
		Fl_Choice* sim = new Fl_Choice(340, 5 ,65,25, "Simplify Alg.");
		sim->add("QEM", 0, (Fl_Callback*)simplify_menu_callback);
		sim->add("Memoryless", 0, (Fl_Callback*)simplify_menu_callback);
		sim->add("others", 0, (Fl_Callback*)simplify_menu_callback);
		Fl_Button* simplify = new Fl_Button(260,40, 145 ,25,"Simplify");
		simplify->callback((Fl_Callback*) Simplify_CB, gl);
		
		//Parameterization algorithm chooser
		// try to add your menu chooser and button here
		// don't forget to add the menu_callback/button_callback
		// function and its call to the myGLWindow class, which
		// contain the polyhedron(or mesh DS).

	wind->end();
	wind->show();	// this actually opens the window
	
	Fl::add_idle((void (*)(void*))Redraw_CB, gl);
	Fl::run();
	delete gl;

    return 0;
}